from django.conf import settings
from django.urls import re_path

if settings.ALDRYN_DJANGO_ENABLE_GIS:
    from django.contrib.gis import admin
else:
    from django.contrib import admin


admin.autodiscover()

urlpatterns = [
    re_path(r'^admin/', admin.site.urls),
]



from django.conf import settings
from django.conf.urls.i18n import i18n_patterns as django_i18n_patterns


def i18n_patterns(*args):
    """
    We want to avoid having to change anything in the projects
    root urls.py when new versions of Django are released.
    """
    use_prefix = getattr(settings, 'PREFIX_DEFAULT_LANGUAGE', True)
    return django_i18n_patterns(*args, prefix_default_language=use_prefix)



# -*- coding: utf-8 -*-
import sys
from setuptools import setup, find_packages
from aldryn_django import __version__


if sys.version_info[0] == 2:
    # on python2 the backport of subprocess32 is needed
    extra_dependencies = (
        'subprocess32',
    )
else:
    extra_dependencies = ()


setup(
    name='aldryn-django',
    version=__version__,
    description='An opinionated Django setup bundled as an Aldryn Addon',
    author='Divio AG',
    author_email='info@divio.ch',
    url='https://github.com/aldryn/aldryn-django',
    packages=find_packages(),
    install_requires=(
        'aldryn-addons',
        'Django==2.1.5',

        # setup utils
        'dj-database-url',
        'dj-email-url',
        'dj-redis-url',
        'django-cache-url',
        'django-getenv',
        'aldryn-client',
        'yurl',

        # error reporting
        'raven',

        # wsgi server related
        'uwsgi',
        'dj-static',

        # database
        'psycopg2',

        # storage
        'django-storages',
        'boto>=2.40.0',
        'djeese-fs',

        # helpers
        'click',
        'aldryn-sites>=0.5.6',

        'easy-thumbnails>=2.2.1.1',
    ) + extra_dependencies,
    entry_points='''
        [console_scripts]
        aldryn-django=aldryn_django.cli:main
    ''',
    include_package_data=True,
    zip_safe=False,
)
